@@ -21,7 +21,7 @@
 #ifndef __GENRE_H__
 #define __GENRE_H__
 
-char *genre_table[] = {"Blues",
+static const char *genre_table[] = {"Blues",
                        "Classic Rock",
                        "Country",
                        "Dance",
@@ -178,7 +178,7 @@ char *genre_table[] = {"Blues",
 		       "Synthpop",
                        };
 
-const int genre_count = 148;
+static const unsigned genre_count = 148;
 
 
 #endif /* __GENRE_H__ */
